==> junit-servers-core-0.11.0-sources.jar: com/github/mjeanroy/junit/servers/jupiter/ConfigurationResolverFunction.java <==
/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2018 <mickael.jeanroy@gmail.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.github.mjeanroy.junit.servers.jupiter;

import com.github.mjeanroy.junit.servers.engine.EmbeddedServerTestLifeCycleAdapter;
import org.junit.jupiter.api.extension.ParameterContext;

/**
 * Resolve {@link com.github.mjeanroy.junit.servers.servers.AbstractConfiguration} parameter.
 */
class ConfigurationResolverFunction implements ParameterResolverFunction {

	/**
	 * The singleton instance.
	 */
	private static final ConfigurationResolverFunction INSTANCE = new ConfigurationResolverFunction();

	/**
	 * Get instance of {@link ConfigurationResolverFunction} resolver.
	 *
	 * @return The instance.
	 */
	static ConfigurationResolverFunction getInstance() {
		return INSTANCE;
	}

	// Ensure non public instantiation.
	private ConfigurationResolverFunction() {
	}

	@Override
	public Object resolve(ParameterContext parameterContext, EmbeddedServerTestLifeCycleAdapter serverAdapter) {
		return serverAdapter.getServer().getConfiguration();
	}
}

==> junit-servers-core-2.0.0-sources.jar: com/github/mjeanroy/junit/servers/jupiter/ConfigurationResolverFunction.java <==
/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2019 <mickael.jeanroy@gmail.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.github.mjeanroy.junit.servers.jupiter;

import com.github.mjeanroy.junit.servers.engine.EmbeddedServerRunner;
import com.github.mjeanroy.junit.servers.loggers.Logger;
import com.github.mjeanroy.junit.servers.loggers.LoggerFactory;
import org.junit.jupiter.api.extension.ParameterContext;

/**
 * Resolve {@link com.github.mjeanroy.junit.servers.servers.AbstractConfiguration} parameter.
 */
class ConfigurationResolverFunction implements ParameterResolverFunction {

	/**
	 * Class Logger.
	 */
	private static final Logger log = LoggerFactory.getLogger(ConfigurationResolverFunction.class);

	/**
	 * The singleton instance.
	 */
	private static final ConfigurationResolverFunction INSTANCE = new ConfigurationResolverFunction();

	/**
	 * Get instance of {@link ConfigurationResolverFunction} resolver.
	 *
	 * @return The instance.
	 */
	static ConfigurationResolverFunction getInstance() {
		return INSTANCE;
	}

	// Ensure non public instantiation.
	private ConfigurationResolverFunction() {
	}

	@Override
	public Object resolve(ParameterContext parameterContext, EmbeddedServerRunner serverAdapter) {
		log.debug("Resolving embedded server configuration for parameter: {}", parameterContext);
		return serverAdapter.getServer().getConfiguration();
	}
}
